@@ -1,4 +1,5 @@
 #! /usr/bin/env python
+'''a dispatcher to simply call a callback function on each connection'''
 
 from .misc import init_logger
 
@@ -9,4 +10,5 @@ class RawSocketDispatcher(object):
 		self.callback = callback
 
 	def handle_connection(self, clientsocket, address, client_id):
+		'''calls the callback on the socket connection'''
 		self.callback(clientsocket, address, client_id)
